@@ -3,12 +3,12 @@
 /** 
  * Version of liboqs as a string. Equivalent to {MAJOR}.{MINOR}.{PATCH}{PRE_RELEASE} 
  */
-#define OQS_VERSION_TEXT "0.13.0"
+#define OQS_VERSION_TEXT "0.14.0"
 /** 
  * Version levels of liboqs as integers.
  */
 #define OQS_VERSION_MAJOR 0
-#define OQS_VERSION_MINOR 13
+#define OQS_VERSION_MINOR 14
 #define OQS_VERSION_PATCH 0
 /** 
  * OQS_VERSION_PRE_RELEASE is defined if this is a pre-release version of liboqs, otherwise it is undefined.
@@ -16,7 +16,7 @@
  */
 /* #undef OQS_VERSION_PRE_RELEASE */
 
-#define OQS_COMPILE_BUILD_TARGET "earmv6hf-NetBSD-10.0"
+#define OQS_COMPILE_BUILD_TARGET "riscv64-NetBSD-11.0"
 #define OQS_DIST_BUILD 1
 /* #undef OQS_DIST_X86_64_BUILD */
 /* #undef OQS_DIST_X86_BUILD */
@@ -30,6 +30,7 @@
 /* #undef BUILD_SHARED_LIBS */
 /* #undef OQS_BUILD_ONLY_LIB */
 #define OQS_OPT_TARGET "generic"
+/* #undef USE_COVERAGE */
 /* #undef USE_SANITIZER */
 /* #undef CMAKE_BUILD_TYPE */
 
@@ -68,6 +69,7 @@
 /* #undef OQS_ENABLE_TEST_CONSTANT_TIME */
 
 /* #undef OQS_ENABLE_SHA3_xkcp_low_avx2 */
+/* #undef OQS_USE_SHA3_AVX512VL */
 
 #define OQS_USE_CUPQC 0
 
@@ -290,6 +292,44 @@
 #define OQS_ENABLE_SIG_uov_ov_V_pkc_skc 1
 /* #undef OQS_ENABLE_SIG_uov_ov_V_pkc_skc_neon */
 /* #undef OQS_ENABLE_SIG_uov_ov_V_pkc_skc_avx2 */
+
+#define OQS_ENABLE_SIG_SNOVA 1
+#define OQS_ENABLE_SIG_snova_SNOVA_24_5_4 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_24_5_4_SHAKE 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_SHAKE_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_SHAKE_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_24_5_4_esk 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_esk_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_esk_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_24_5_4_SHAKE_esk 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_SHAKE_esk_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_4_SHAKE_esk_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_37_17_2 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_37_17_2_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_37_17_2_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_25_8_3 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_25_8_3_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_25_8_3_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_56_25_2 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_56_25_2_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_56_25_2_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_49_11_3 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_49_11_3_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_49_11_3_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_37_8_4 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_37_8_4_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_37_8_4_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_24_5_5 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_5_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_24_5_5_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_60_10_4 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_60_10_4_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_60_10_4_neon */
+#define OQS_ENABLE_SIG_snova_SNOVA_29_6_5 1
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_29_6_5_avx2 */
+/* #undef OQS_ENABLE_SIG_snova_SNOVA_29_6_5_neon */
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ADD_ALG_ENABLE_DEFINES_END
 
 ///// OQS_COPY_FROM_LIBJADE_FRAGMENT_ADD_ALG_ENABLE_DEFINES_START
